@@ -17,11 +17,11 @@ WebService::Careerjet - Perl interface to Careerjet's public job offers search A
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-our $VERSION = '0.12' ;
+our $VERSION = '0.13' ;
 
 =head1 SYNOPSIS
 
@@ -180,93 +180,15 @@ Usage:
 
 =cut
    
-my %h_locale2base = ( 
-    cs_CZ  => "http://www.careerjet.cz",
-    da_DK  => "http://www.careerjet.dk",
-    de_AT  => "http://www.careerjet.at",
-    de_CH  => "http://www.careerjet.ch",
-    de_DE  => "http://www.careerjet.de",
-    en_AE  => "http://www.careerjet.ae",
-    en_AU  => "http://www.careerjet.com.au",
-    en_BD  => "http://www.careerjet.com.bd",
-    en_CA  => "http://www.careerjet.ca",
-    en_CN  => "http://en.careerjet.cn",
-    en_HK  => "http://www.careerjet.hk",
-    en_IE  => "http://www.careerjet.ie",
-    en_IN  => "http://www.careerjet.co.in",
-    en_KW  => "http://www.careerjet.com.kw",
-    en_MY  => "http://www.careerjet.com.my",
-    en_NZ  => "http://www.careerjet.co.nz",
-    en_OM  => "http://www.careerjet.com.om",
-    en_PH  => "http://www.careerjet.ph",
-    en_PK  => "http://www.careerjet.com.pk",
-    en_QA  => "http://www.careerjet.com.qa",
-    en_SG  => "http://www.careerjet.sg",
-    en_GB  => "http://www.careerjet.co.uk",
-    en_UK  => "http://www.careerjet.co.uk",
-    en_US  => "http://www.careerjet.com",
-    en_ZA  => "http://www.careerjet.co.za",
-    en_SA  => "http://www.careerjet-saudi-arabia.com",
-    en_TW  => "http://www.careerjet.com.tw",
-    en_VN  => "http://www.careerjet.vn",
-    es_AR  => "http://www.opcionempleo.com.ar",
-    es_BO  => "http://www.opcionempleo.com.bo",
-    es_CL  => "http://www.opcionempleo.cl",
-    es_CO  => "http://www.opcionempleo.com.co",
-    es_CR  => "http://www.opcionempleo.co.cr",
-    es_DO  => "http://www.opcionempleo.com.do",
-    es_EC  => "http://www.opcionempleo.ec",
-    es_ES  => "http://www.opcionempleo.com",
-    es_GT  => "http://www.opcionempleo.com.gt" ,
-    es_MX  => "http://www.opcionempleo.com.mx",
-    es_PA  => "http://www.opcionempleo.com.pa",
-    es_PE  => "http://www.opcionempleo.com.pe",
-    es_PR  => "http://www.opcionempleo.com.pr",
-    es_PY  => "http://www.opcionempleo.com.py",
-    es_UY  => "http://www.opcionempleo.com.uy",
-    es_VE  => "http://www.opcionempleo.com.ve",
-    fi_FI  => "http://www.careerjet.fi",
-    fr_BE  => "http://www.optioncarriere.be",
-    fr_CA  => "http://fr.careerjet.ca" ,
-    fr_CH  => "http://www.optioncarriere.ch",
-    fr_FR  => "http://www.optioncarriere.com",
-    fr_LU  => "http://www.optioncarriere.lu",
-    fr_MA  => "http://www.optioncarriere.ma",
-    hu_HU  => "http://www.careerjet.hu",
-    it_IT  => "http://www.careerjet.it",
-    ja_JP  => "http://www.careerjet.jp",
-    ko_KR  => "http://www.careerjet.co.kr",
-    nl_BE  => "http://www.careerjet.be",
-    nl_NL  => "http://www.careerjet.nl",
-    no_NO  => "http://www.careerjet.no",
-    pl_PL  => "http://www.careerjet.pl",
-    pt_PT  => "http://www.careerjet.pt",
-    pt_BR  => "http://www.careerjet.com.br",
-    ru_RU  => "http://www.careerjet.ru",
-    ru_UA  => "http://www.careerjet.com.ua",
-    sv_SE  => "http://www.careerjet.se",
-    sk_SK  => "http://www.careerjet.sk",
-    tr_TR  => "http://www.careerjet.com.tr",
-    uk_UA  => "http://www.careerjet.ua",
-    vi_VN  => "http://www.careerjet.com.vn",
-    zh_CN  => "http://www.careerjet.cn",
-                      
-    en_XA => "http://beta.careerjet.net" ,
-    ja_XA => "http://betajp.careerjet.net" ,
-);
-
-
 sub new{
     my ($class, $locale) = @_ ;
     $locale ||= 'en_GB';
 
-    my $base = $h_locale2base{$locale} || $h_locale2base{en_GB};
-
     my $ua = LWP::UserAgent->new() ;
     $ua->agent($class.'/'.$VERSION);
     
     my $self = {
-        'base' => $base ,
+        'locale' => $locale ,
         'agent' => $ua ,
         'debug' => 0 ,
     };
@@ -291,10 +213,9 @@ Usage:
 sub _call{
     my ($self, $function, $args) = @_ ;
     
-    my $url = $self->{'base'}.'/devel/'.$function.'.api?' ;
+    my $url = "http://public.api.careerjet.net/$function?locale_code=" . $self->{locale} ;
     foreach my $k ( keys %$args ){
-        $url .= $k.'='.URI::Escape::uri_escape_utf8($args->{$k}).'&';
-        
+        $url .= '&' . $k . '='. URI::Escape::uri_escape_utf8($args->{$k});
     }
     
     print "GETTING ".$url."\n" if ( $self->debug());
@@ -440,7 +361,7 @@ Any feedback is welcome. Please send your suggestions to <api at careerjet.com>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2009 Careerjet Ltd. All rights reserved.
+Copyright 2007-2012 Careerjet Ltd. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
